ClientAccess

Trait ClientAccess 

pub trait ClientAccess {
    type Client;

    // Required method
    fn client(&self) -> Self::Client;
}
Trait for accessing the provider’s native client This is a separate trait to allow generic client types while keeping Authn object-safe

Required Associated Types

Required Methods

fn client(&self) -> Self::Client

Get the client used by this provider

Returns the provider’s native client. For Stytch providers, this returns the Stytch SDK client. For other providers (Clerk, MSAL), this returns a reqwest::Client.

Implementors