pub enum Client {
Reqwest(Client),
Stytch(Arc<Client>),
}Expand description
Client enum that wraps different HTTP/SDK client types This allows each provider to expose its native client while maintaining trait object safety
Variants
Reqwest(Client)
Standard reqwest HTTP client (used by Clerk, MSAL, etc.)
Stytch(Arc<Client>)
Stytch SDK client for advanced Stytch operations
Implementations