pub trait ClientAccess {
type Client;
// Required method
fn client(&self) -> Self::Client;
}Expand description
Trait for accessing the provider’s native client This is a separate trait to allow generic client types while keeping Authn object-safe